@@ -67,8 +67,8 @@ class TaskInfo:
 class PrometheusEcsDiscoverer:
     """The disoverer.
 
-    Consists out of two main methods. One gets all the task infos and the 
-    second one takes these task infos and tries to build target objects from 
+    Consists out of two main methods. One gets all the task infos and the
+    second one takes these task infos and tries to build target objects from
     them.
     """
 
@@ -184,7 +184,9 @@ class PrometheusEcsDiscoverer:
         task_arn = data.task["taskArn"]
 
         _logger = logger.bind(
-            container=container_name, task_definition=task_definition_arn, task=task_arn,
+            container=container_name,
+            task_definition=task_definition_arn,
+            task=task_arn,
         )
 
         for defi in data.task_definition["containerDefinitions"]:
@@ -224,7 +226,7 @@ class PrometheusEcsDiscoverer:
         port = _extract_port(
             network_mode,
             prom_port,
-            toolbox.extract_env_var(container, "PROMETHEUS_CONTAINER_PORT"),
+            toolbox.extract_env_var(container_definition, "PROMETHEUS_CONTAINER_PORT"),
             port_mappings,
             network_bindings,
         )
